@@ -1,9 +1,7 @@
-load_params = function(group = c("sleep", "metrics", "rawdata",
+load_params = function(topic = c("sleep", "metrics", "rawdata",
                                  "247", "phyact", "cleaning",
                                  "output", "general")) {
-  if (length(group) == 0) {
-    warning("\nArgument group not specified in load_params")
-  }
+
   # initialize params objects
   params_sleep = params_metrics = params_rawdata = c()
   params_247 = params_phyact = params_cleaning = c()
@@ -12,7 +10,7 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
   # if (length(jsonfile) > 0) {
   #   # PLACEHOLDER FOR WHEN JSON FILE CONFIG FILE WILL BE FACILITATE
   # } else {
-  if ("sleep" %in% group) {
+  if ("sleep" %in% topic) {
     params_sleep = list(anglethreshold = 5, timethreshold = 5,
                         ignorenonwear = TRUE, constrain2range = TRUE,
                         HASPT.algo = "HDCZA",
@@ -29,7 +27,7 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
                         nap_model = c(), sleepefficiency.metric = 1,
                         possible_nap_edge_acc = Inf)
   }
-  if ("metrics" %in% group) {
+  if ("metrics" %in% topic) {
     params_metrics = list(do.anglex = FALSE, do.angley = FALSE, do.anglez = TRUE,
                           do.zcx = FALSE, do.zcy = FALSE, do.zcz = FALSE,
                           do.enmo = TRUE, do.lfenmo = FALSE, do.en = FALSE,
@@ -47,7 +45,7 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
                           zc.lb = 0.25, zc.hb = 3, zc.sb = 0.01, zc.order = 2, zc.scale = 1,
                           actilife_LFE = FALSE)
   }
-  if ("rawdata" %in% group) {
+  if ("rawdata" %in% topic) {
     params_rawdata = list(
       chunksize = 1, spherecrit = 0.3, minloadcrit = 72, printsummary = FALSE,
       do.cal = TRUE, backup.cal.coef = "retrieve", dynrange = c(),
@@ -67,7 +65,7 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
       interpolationType = 1,
       imputeTimegaps = TRUE, frequency_tol = 0.1, rmc.scalefactor.acc = 1)
   }
-  if ("247" %in% group) {
+  if ("247" %in% topic) {
     params_247 = list(qwindow = c(0,24), qlevels = c(),
                       qwindow_dateformat = "%d-%m-%Y", ilevels = c(),
                       IVIS_windowsize_minutes = 60, IVIS_epochsize_seconds = c(),
@@ -75,20 +73,24 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
                       MX.ig.min.dur = 10, M5L5res = 10, winhr = 5, iglevels = c(),
                       LUXthresholds = c(0, 100, 500, 1000, 3000, 5000, 10000),
                       LUX_cal_constant = c(), LUX_cal_exponent = c(), LUX_day_segments = c(),
-                      window.summary.size = 10, L5M5window = c(0, 24), cosinor = FALSE)
+                      L5M5window = c(0, 24), cosinor = FALSE,
+                      part6CR = FALSE, part6HCA = FALSE,
+                      part6Window = c("start", "end"))
   }
-  if ("phyact" %in% group) {
+  if ("phyact" %in% topic) {
     params_phyact = list(mvpathreshold = 100, boutcriter = 0.8,
                          mvpadur = c(1,5,10),
                          boutcriter.in = 0.9, boutcriter.lig = 0.8,
                          boutcriter.mvpa = 0.8, threshold.lig = 40,
                          threshold.mod = 100, threshold.vig = 400,
                          boutdur.mvpa = c(1,5,10), boutdur.in = c(10,20,30),
-                         boutdur.lig = c(1,5,10), frag.metrics = c())
+                         boutdur.lig = c(1,5,10), frag.metrics = c(),
+                         part6_threshold_combi = "40_100_400")
   }
-  if ("cleaning" %in% group) {
+  if ("cleaning" %in% topic) {
     params_cleaning = list(includedaycrit = 16, ndayswindow = 7,
-                           strategy = 1, maxdur = 0,
+                           strategy = 1, data_masking_strategy = 1,
+                           maxdur = 0,
                            hrs.del.start = 0, hrs.del.end = 0,
                            includedaycrit.part5 = 2/3, excludefirstlast.part5 = FALSE,
                            TimeSegments2ZeroFile = c(), do.imp = TRUE,
@@ -99,9 +101,10 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
                            excludelast.part4 = FALSE, max_calendar_days = 0,
                            nonWearEdgeCorrection = TRUE, nonwear_approach = "2023",
                            segmentWEARcrit.part5 = 0.5,
-                           segmentDAYSPTcrit.part5 = c(0.9, 0))
+                           segmentDAYSPTcrit.part5 = c(0.9, 0),
+                           study_dates_file = c(), study_dates_dateformat = "%d-%m-%Y")
   }
-  if ("output" %in% group) {
+  if ("output" %in% topic) {
     params_output = list(epochvalues2csv = FALSE, save_ms5rawlevels = FALSE,
                          save_ms5raw_format = "csv", save_ms5raw_without_invalid = TRUE,
                          storefolderstructure = FALSE, timewindow = c("MM","WW"),
@@ -112,7 +115,7 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
                          sep_reports = ",", sep_config = ",", visualreport_without_invalid = TRUE)
 
   }
-  if ("general" %in% group) {
+  if ("general" %in% topic) {
     params_general = list(overwrite = FALSE, acc.metric = "ENMO",
                           maxNcores = c(), print.filename = FALSE,
                           do.parallel = TRUE, windowsizes = c(5,900,3600),
@@ -123,7 +126,6 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
                           dataFormat = "raw", maxRecordingInterval = NULL,
                           extEpochData_timeformat = "%d-%m-%Y %H:%M:%S")
   }
-  # }
   invisible(list(params_sleep = params_sleep,
                  params_metrics = params_metrics,
                  params_rawdata = params_rawdata,
