@@ -32,8 +32,8 @@ test_that("External epoch data is correctly converted", {
   params_general[["windowsizes"]][1] = 60
   params_general[["dataFormat"]] = "actiwatch_awd"
   params_general[["extEpochData_timeformat"]] = "%d-%b-%Y %H:%M:%S"
-  convertEpochData(datadir = dn, studyname = "tmp_testdata", outputdir = ".",
-                              params_general = params_general)
+  convertEpochData(datadir = dn, metadatadir = "./output_tmp_testdata",
+                   params_general = params_general)
   
   if (dir.exists(dn))  unlink(dn, recursive = TRUE)
   load(paste0(QCbasis, "/meta_Actiwatch.AWD.RData"))
@@ -49,10 +49,10 @@ test_that("External epoch data is correctly converted", {
   params_general[["windowsizes"]][1] = 15
   params_general[["dataFormat"]] = "actiwatch_csv"
   params_general[["extEpochData_timeformat"]] = "%d-%m-%Y %H:%M:%S"
-  expect_error(convertEpochData(datadir = dn, studyname = "tmp_testdata", outputdir = ".",
-                   params_general = params_general))
+  expect_error(convertEpochData(datadir = dn, metadatadir = "./output_tmp_testdata",
+               params_general = params_general))
   params_general[["extEpochData_timeformat"]] = "%d/%m/%Y %H:%M:%S"
-  convertEpochData(datadir = dn, studyname = "tmp_testdata", outputdir = ".",
+  convertEpochData(datadir = dn, metadatadir = "./output_tmp_testdata",
                    params_general = params_general)
   if (dir.exists(dn))  unlink(dn, recursive = TRUE)
   load(paste0(QCbasis, "/meta_Actiwatch.csv.RData"))
@@ -67,7 +67,7 @@ test_that("External epoch data is correctly converted", {
   move2folder(system.file("testfiles/ukbiobank.csv", package = "GGIR")[1], dn)
   params_general[["windowsizes"]][1] = 5
   params_general[["dataFormat"]] = "ukbiobank_csv"
-  convertEpochData(datadir = dn, studyname = "tmp_testdata", outputdir = ".",
+  convertEpochData(datadir = dn, metadatadir = "./output_tmp_testdata",
                    params_general = params_general)
   if (dir.exists(dn))  unlink(dn, recursive = TRUE)
   load(paste0(QCbasis, "/meta_ukbiobank.csv.RData"))
@@ -83,7 +83,7 @@ test_that("External epoch data is correctly converted", {
   params_general[["windowsizes"]][1] = 5
   params_general[["dataFormat"]] = "actigraph_csv"
   params_general[["extEpochData_timeformat"]] = "%m/%d/%Y %H:%M:%S"
-  convertEpochData(datadir = dn, studyname = "tmp_testdata", outputdir = ".",
+  convertEpochData(datadir = dn, metadatadir = "./output_tmp_testdata",
                    params_general = params_general)
   if (dir.exists(dn))  unlink(dn, recursive = TRUE)
   load(paste0(QCbasis, "/meta_ActiGraph61.csv.RData"))
@@ -100,7 +100,7 @@ test_that("External epoch data is correctly converted", {
   params_general[["windowsizes"]][1] = 15
   params_general[["dataFormat"]] = "actigraph_csv"
   params_general[["extEpochData_timeformat"]] = "%m/%d/%Y %H:%M:%S"
-  convertEpochData(datadir = dn, studyname = "tmp_testdata", outputdir = ".",
+  convertEpochData(datadir = dn, metadatadir = "./output_tmp_testdata",
                    params_general = params_general)
   if (dir.exists(dn))  unlink(dn, recursive = TRUE)
   load(paste0(QCbasis, "/meta_ActiGraph13.csv.RData"))
